@@ -1,4 +1,6 @@
-from pygismeteo_base.models import (
+from __future__ import annotations
+
+from . import (
     current,
     search_by_coordinates,
     search_by_ip,
